'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _jimp = require('jimp');

var _jimp2 = _interopRequireDefault(_jimp);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _isUrl = require('is-url');

var _isUrl2 = _interopRequireDefault(_isUrl);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _webCapture = require('web-capture');

var _webCapture2 = _interopRequireDefault(_webCapture);

var _colorExtract = require('color-extract');

var _colorBlocks = require('color-blocks');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CACHEA = _path2.default.resolve(__dirname, '5fba6621adbd97fec1d933874bf49e5a.png');
var CACHEB = _path2.default.resolve(__dirname, '5fba6621adbd97fec1d933874bf49e5b.png');

// Resizes the cache files.@
var resizeCache = function resizeCache() {
  return new _bluebird2.default(function (resolve, reject) {
    _jimp2.default.read(CACHEA).then(function (img) {
      img.resize(100, 100).write(CACHEB, function (err) {
        if (err) {
          reject(err);
        }
        resolve();
      });
    });
  });
};

// Clears the cache.
var clearCache = function clearCache() {
  _fsExtra2.default.removeSync(CACHEA);
  _fsExtra2.default.removeSync(CACHEB);
};

/**
 * Fetches the given amount of colors from the given url. This can be used to determine the color
 * scheme that is used on the given website. An optional output location can be given, which will
 * be the location of the output file (if undefined, no file will be created).
 * @param {string} url The url of the website to check
 * @param {number} amount The amount of colors to fetch
 * @param {?string} output The output location for the theme file
 * @returns {Promise<Color>} A promise with the color scheme
 */

exports.default = function (url, amount, output) {
  return new _bluebird2.default(function (resolve, reject) {
    if ((0, _isUrl2.default)(url)) {
      (0, _webCapture2.default)(url, CACHEA).then(function () {
        return resizeCache();
      }).then(function () {
        return (0, _colorExtract.getProminentColors)(CACHEB, amount);
      }).then(function (colors) {
        if (output) {
          var aop = _path2.default.resolve(process.cwd(), output);
          var outputPath = _path2.default.extname(aop) === '.png' ? aop : _path2.default.resolve(aop, 'output.png');
          (0, _colorBlocks.createColorPattern)(50, colors, outputPath).then(function () {
            resolve(colors);
          }).catch(reject);
        } else {
          resolve(colors);
        }
      }).catch(function (error) {
        return reject(error);
      });
    } else {
      reject('Invalid url provided.');
    }
  }).finally(function () {
    return clearCache();
  });
};